OC.L10N.register(
    "circles",
    {
    "Circles" : "Kreise",
    "Circles' files" : "Dateien der Kreise",
    "Select circles to filter by" : "Kreise wählen, um hiernach zu filtern",
    "No circles found" : "Keine Kreise gefunden",
    "Please select circles to filter by" : "Bitte Kreise wählen, um hiernach zu filtern",
    "No files found for the selected circles" : "Keine Dateien für die ausgewählten Kreise gefunden",
    "You created the circle {circle}" : "Du hast den Kreis {circle} erstellt",
    "{author} created the circle {circle}" : "{author} hat den Kreis {circle} erstellt",
    "You deleted {circle}" : "Du hast {circle} gelöscht",
    "{author} deleted {circle}" : "{author} hat {circle} gelöscht",
    "You linked {group} to {circle}" : "Du hast eine Verknüpfung von {group} mit {circle} hinzugefügt",
    "{group} has been linked to {circle} by {author}" : "{group} wurde von {author} mit {circle} verknüpft",
    "You unlinked {group} from {circle}" : "Du hast die Verknüpfung der {group} mit {circle} entfernt",
    "{group} has been unlinked from {circle} by {author}" : "Verknüpfung von {group} zu {circle} wurde von {author} gelöst",
    "You changed the level of the linked group {group} in {circle} to %1$s" : "Du hast den Rang der verknüpften Gruppe {group} in {circle} zu %1$s geändert",
    "{author} changed the level of the linked group {group} in {circle} to %1$s" : "{author} hat den Rang der verknüpften Gruppe {group} in {circle} zu %1$s geändert",
    "You sent a request to link {circle} with {remote}" : "Du hast eine Anfrage zum Verknüpfen von {circle} mit {remote} gesendet",
    "{author} sent a request to link {circle} with {remote}" : "{author} hat eine Verknüpfung von {circle} mit {remote} angefordert",
    "{remote} requested a link with {circle}" : "{remote} hat eine Verknüpfung mit {circle} angefordert",
    "The request to link {circle} with {remote} has been rejected" : "Die Anfrage {circle} mit {remote} zu verknüpfen wurde auf dem entfernten System zurückgewiesen",
    "The request to link {remote} with {circle} has been canceled remotely" : "Die Anfrage {remote} mit {circle} zu verknüpfen wurde auf dem entfernten System abgebrochen",
    "The request to link {circle} with {remote} has been accepted" : "Die Anfrage {circle} mit {remote} zu verknüpfen wurde auf dem entfernten System angenommen",
    "You dismissed the request to link {remote} with {circle}" : "Du hast eine Anfrage zum Verknüpfen von {remote} mit {circle} verworfen",
    "{author} dismissed the request to link {remote} with {circle}" : "{author} hat eine Anfrage zum Verknüpfen von {remote} mit {circle} verworfen",
    "You canceled the request to link {circle} with {remote}" : "Du hast eine Anfrage zum Verknüpfen von {circle} mit {remote} abgebrochen",
    "{author} canceled the request to link {circle} with {remote}" : "{author} hat eine Anfrage zum Verknüpfen von {circle} mit {remote} abgebrochen",
    "You accepted the request to link {remote} with {circle}" : "Du hast eine Anfrage zum Verknüpfen von {remote} mit {circle} angenommen",
    "{author} accepted the request to link {remote} with {circle}" : "{author} hat eine Anfrage zum Verknüpfen von {remote} mit {circle} angenommen",
    "A link between {circle} and {remote} is now up and running" : "Die Verknüpfung von {circle} mit {remote} wurde erstellt und funktioniert.",
    "The link between {circle} and {remote} has been shutdown remotely" : "Die Verknüpfung von {circle} mit {remote} wurde auf dem entfernten System beendet",
    "You closed the link between {circle} and {remote}" : "Du hast die Verknüpfung von {circle} mit {remote} beendet",
    "{author} closed the link between {circle} and {remote}" : "{author} hat die Verknüpfung von {circle} mit {remote} beendet",
    "You joined {circle}" : "Du bist dem {circle} beigetreten",
    "{member} joined {circle}" : "{member} ist {circle} beigetreten",
    "You accepted the invitation to join {circle}" : "Du hast die Einladung angenommen {circle} beizutreten",
    "{member} accepted the invitation to join {circle}" : "{member} hat die Einladung angenommen {circle} beizutreten",
    "You added {member} as member to {circle}" : "Du hast {member} dem Kreis {circle} hinzugefügt",
    "You have been added as member to {circle} by {author}" : "Du wurdest von {author} als Mitglied zu {circle} hinzugefügt",
    "{member} has been added as member to {circle} by {author}" : "{member} wurde von {author} als Mitglied zu {circle} hinzugefügt",
    "You added {external} to {circle}" : "Du hast {external} zu {circle} hinzugefügt",
    "{external} has been added to {circle} by {author}" : "{external} wurde von {author} zu {circle} hinzugefügt",
    "You accepted {member}'s request to join {circle}" : "Du hast die Anfrage von {member}, {circle} beizutreten, angenommen",
    "Your request to join {circle} has been accepted by {author}" : "Deine Anfrage {circle} beizutreten wurde von {author} angenommen",
    "{member}'s request to join {circle} has been accepted by {author}" : "Die Anfrage von {member}, {circle} beizutreten, wurde von {author} angenommen",
    "You left {circle}" : "Du hast {circle} verlassen",
    "{member} left {circle}" : "{member} hat {circle} verlassen",
    "You declined the invitation to join {circle}" : "Du hast die Einladung {circle} beizutreten abgelehnt",
    "{member} declined an invitation to join {circle}" : "{member} hat es abgelehnt {circle} beizutreten",
    "You cancelled your request to join {circle}" : "Du hast deine Anfrage  {circle} beizutreten zurückgezogen",
    "{member} cancelled his request to join {circle}" : "{member} hat seine Anfrage {circle} beizutreten zurückgezogen",
    "You removed {member} from {circle}" : "Du hast {member} aus {circle} entfernt",
    "You have been removed from {circle} by {author}" : "Du wurdest von {author} aus {circle} entfernt",
    "{member} has been removed from {circle} by {author}" : "{member} wurde von {author} aus {circle} entfernt",
    "You removed {external} from {circle}" : "Du hast {external} von {circle} entfernt",
    "{external} has been removed from {circle} by {author}" : "{external} wurde von {author} von {circle} entfernt",
    "You cancelled {member}'s invitation to join {circle}" : "Du hast die Einladung an {member} {circle} beizutreten zurückgezogen",
    "Your invitation to join {circle} has been cancelled by {author}" : "Deine Einladung {circle} beizutreten wurde von {author} zurückgezogen",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author} hat die Einladung an {member} {circle} beizutreten zurückgezogen",
    "You dismissed {member}'s request to join {circle}" : "Du hast die Anfrage von {member}, {circle} beizutreten, abgelehnt",
    "Your request to join {circle} has been dismissed by {author}" : "Deine Anfrage {circle} beizutreten wurde von {author} abgelehnt",
    "{member}'s request to join {circle} has been dismissed by {author}" : "Die Anfrage von {member}, {circle} beizutreten, wurde von {author} abgelehnt",
    "You invited {member} to join {circle}" : "Du hast {member} eingeladen {circle} beizutreten",
    "You have been invited to join {circle} by {author}" : "Du wurdest von {author} eingeladen {circle} beizutreten",
    "{member} has been invited to join {circle} by {author}" : "{member} wurde von {author} eingeladen {circle} beizutreten",
    "You changed {member}'s level in {circle} to %1$s" : "Du hast den Rang von {member}  in {circle} zu %1$s geändert",
    "{author} changed your level in {circle} to %1$s" : "{author} hat deinen Rang in {circle} zu %1$s geändert",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author} hat den Rang von {member} in {circle} zu %1$s geändert",
    "You sent a request to join {circle}" : "Du hast eine Anfrage gestellt in {circle} aufgenommen zu werden",
    "{member} sent a request to join {circle}" : "{member} hat eine Anfrage gestellt in {circle} aufgenommen zu werden",
    "You are the new owner of {circle}" : "Du bist der neue Eigentümer von {circle}",
    "{member} is the new owner of {circle}" : "{member} ist der neue Eigentümer von {circle}",
    "On events happening in a <strong>Circle</strong> of which you are a member" : "Bei Ereignissen in einem <strong>Kreis</strong> , in dem du Mitglied bist",
    "Any important event in a <strong>Circle</strong> you are moderating" : "Irgend ein wichtiger Termin in einem <strong>Kreis</strong>, den du moderierst",
    "On global events happening in any <strong>Circle</strong>" : "Bei globalen Ereignissen in irgendeinem <strong>Kreis</strong> ",
    "Single" : "Einzeln",
    "Personal" : "Persönlich",
    "System" : "System",
    "Visible" : "Sichtbar",
    "Open" : "Offen",
    "Invite" : "Einladen",
    "Join Request" : "Betrittsanfrage",
    "Friends" : "Freunde",
    "Password Protected" : "Passwortgeschützt",
    "No Owner" : "Kein Besitzer",
    "Hidden" : "Versteckt",
    "Backend" : "Backend",
    "Local" : "Lokal",
    "Root" : "Root",
    "Circle Invite" : "Einladung zu Kreis",
    "Federated" : "Federated",
    "Mount point" : "Einhängepunkt",
    "Nextcloud Account" : "Nextcloud-Konto",
    "Nextcloud Group" : "Nextcloud-Gruppe",
    "Email Address" : "E-Mail-Adresse",
    "Contact" : "Kontakt",
    "Circle" : "Kreis",
    "Nextcloud App" : "Nextcloud-App",
    "Member" : "Mitglied",
    "Moderator" : "Moderator",
    "Admin" : "Administrator",
    "Owner" : "Eigentümer",
    "%s shared »%s« with you." : "%s hat »%s« mit dir geteilt.",
    "%s shared »%s« with \"%s\"." : "%s hat »%s« mit \"%s\" geteilt.",
    "%s on %s" : "%s in %s",
    "%1$s shared »%2$s« with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s hat »%2$s« mit dir geteilt.\nDu solltest bereits eine weitere E-Mail mit einem Link für den Zugriff erhalten haben.\n",
    "%1$s shared »%2$s« with you. You should have already received a separate email with a link to access it." : "%1$s hat »%2$s« mit dir geteilt. Du solltest bereits eine weitere E-Mail mit einem Link für den Zugriff erhalten haben. ",
    "Password to access »%1$s« shared to you by %2$s" : "Das Passwort zum Zugriff auf %1$s wurde dir von  %2$s mitgetelt.",
    "Password to access »%s«" : "Passwort um auf »%s« zu zugreifen",
    "It is protected with the following password:" : "Dies ist mit dem folgendem Passwort geschützt:",
    "%1$s via %2$s" : "%1$s über %2$s",
    "Click the button below to open it." : "Zum Öffnen auf die untenstehende Schaltfläche klicken.",
    "Open »%s«" : "Öffne »%s«",
    "%1$s shared multiple files with you.\nYou should have already received a separate email with a link to access them.\n" : "%1$s hat mehrere Dateien mit dir geteilt.\nDu solltest bereits eine weitere E-Mail mit einem Link für den Zugriff erhalten haben.\n",
    "%1$s shared multiple files with you. You should have already received a separate email with a link to access them." : "%1$s hat mehrere Dateien mit dir geteilt. Du solltest bereits eine weitere E-Mail mit einem Link für den Zugriff erhalten haben. ",
    "Password to access files shared to you by %1$s" : "Passwort für den Zugriff auf die von %1$s für dich freigegebenen Dateien",
    "Password to access files" : "Passwort für den Dateizugriff",
    "%s shared multiple files with \"%s\"." : "%s hat mehrere Dateien mit \"%s\" geteilt.",
    "%s shared multiple files with you." : "%s hat mehrere Dateien mit dir geteilt.",
    "Boot up" : "Hochfahren",
    "Fresh installation status" : "Aktueller Initialisierungsstatus",
    "Building Local Database" : "Lokale Datenbank wird erstellt",
    "Testing Basic Circle Creation" : "Testen der grundlegenden Kreiserstellung",
    "Adding local users and moderators" : "Lokale Benutzer und Moderatoren werden hinzugefügt",
    "Circle not found" : "Kreis nicht gefunden",
    "Circle not found " : "Kreis nicht gefunden",
    "This member does not exist" : "Dieses Mitglied existiert nicht",
    "This account is already a member of the circle" : "Dieses Konto ist bereits Mitglied dieses Kreises",
    "Federated link not found" : "Federated-Verknüpfung nicht gefunden",
    "This feature is not available for personal circles" : "Diese Funktion steht für persönliche Kreise nicht zur Verfügung",
    "The circle is not federated" : "Der Kreis ist nicht cloud übergreifend",
    "You cannot join this circle" : "Du kannst diesem Kreis nicht beitreten",
    "This member is not a moderator" : "Dieses Mitglied ist kein Moderator",
    "Insufficient privileges" : "Nicht ausreichende Berechtigungen ",
    "This member is the owner of the circle" : "Dieses Mitglied ist der Besitzer des Kreises",
    "Level cannot be changed for this type of member" : "Berechtigungsstufe kann für diesen Mitgliedstyp nicht geändert werden",
    "You are already a member of this circle" : "Du bist bereits Mitglied dieses Kreises",
    "You have been blocked from this circle" : "Du wurdest für diesen Kreis blockiert",
    "The account is already a member of this circle" : "Dieses Konto ist bereits Mitglied dieses Kreises",
    "The account has already been invited into this circle" : "Dieser Benutzer wurde bereits zu diesem Kreis eingeladen.",
    "%s (Circle owned by %s)" : "%s (Kreis im Besitz von%s)",
    "You are now a member of the Circle \"%2$s\"" : "Du bist jetzt ein Mitglied des Kreises \"%2$s\"",
    "You have been invited by %1$s into the Circle \"%2$s\"" : "Du wurdest von %1$s zum Kreis \"%2$s\" eingeladen",
    "%1$s sent a request to be a member of the Circle \"%2$s\"" : "%1$s hat eine Mitgliedschaftsanfrage für den Kreis \"%2$s\" gesendet",
    "Accept" : "Annehmen",
    "Refuse" : "Ablehnen",
    "Leave the circle" : "Diesen Kreis verlassen",
    "%s" : "%s",
    "Personal Circle" : "Persönlicher Kreis",
    "%s owned by %s" : "%s gehört %s",
    "You need a specify a type of circle" : "Du benötigst einen bestimmten Kreis-Typ",
    "A circle with that name exists" : "Ein Kreis mit diesem Namen existiert bereits",
    "This member is not the owner of the circle" : "Dieses Mitglied ist nicht der Besitzer des Kreises",
    "This member is not an admin of the circle" : "Dieses Mitglied ist nicht der Administrator des Kreises ",
    "Group contains too many members" : "Gruppe hat zu viele Mitglieder",
    "This group does not exist" : "Diese Gruppe existiert nicht",
    "This group is already linked to the circle" : "Diese Gruppe ist bereits mit diesem Kreis verknüpft",
    "You cannot edit level in a personal circle" : "Du kannst das Level in einem persönlichen Kreis nicht bearbeiten",
    "Group cannot be set as owner of a circle" : "Eine Gruppe kann nicht Besitzer eines Kreises sein",
    "now" : "jetzt",
    "This account does not exist" : "Dieses Konto existiert nicht",
    "Email format is not valid" : "Das E-Mail-Format ist ungültig",
    "This contact is not available" : "Dieser Kontakt ist nicht verfügbar",
    "You have no permission to create a new circle" : "Du hast keine Berechtigung, einen neuen Kreis zu erstellen",
    "%s shared a file with \"%s\"." : "%s hat eine Datei mit \"%s\" geteilt",
    "%s shared a file with you." : "%s hat eine Datei mit dir geteilt.",
    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s hat einen Inhalt mit dir geteilt.\nDu solltest bereits eine weitere E-Mail mit einem Link für den Zugriff erhalten haben.\n",
    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s hat einen Inhalt mit dir geteilt. Du solltest bereits eine weitere E-Mail mit einem Link für den Zugriff erhalten haben.",
    "Password to access content shared with you by %1$s" : "Passwort für den Zugriff auf den Inhalt, der von %1$s mit dir geteilt wurde.",
    "Password to access content" : "Passwort für den Zugriff auf den Inhalt",
    "This item is already shared with this circle" : "Dieses Element wird bereits mit diesem Kreis geteilt",
    "Bring cloud-users closer together." : "Bringe Cloudnutzer näher zueinander.",
    "Circles allows people to create their own groups of people/colleagues/friends.\nThose groups of people (or \"circles\") can then be used by any other app for sharing purpose." : "Mit Kreisen können deine Benutzer ihre eigenen Gruppen von Benutzern/Kollegen/Freunden erstellen.\nDiese Benutzergruppen (oder \"Kreise\") können dann von jeder anderen App zum Zweck der gemeinsamen Nutzung verwendet werden.",
    "No files in here" : "Keine Dateien vorhanden",
    "No entries found in this folder" : " Keine Einträge in diesem Ordner gefunden ",
    "Name" : "Name",
    "Size" : "Größe",
    "Modified" : "Geändert",
    "Nextcloud User" : "Nextcloud-Benutzer",
    "Initialisation Nextcloud" : "Initialisierung von Nextcloud",
    "Initialisation Circles App" : "Initialisierung der Circles-App",
    "You cannot use the Circles Application until your administrator has allowed at least one type of circles" : "Du kannst die Kreise-App nicht verwenden, solange dein Administrator nicht wenigstens einen Kreis-Typ zulässt",
    "This user is already a member of the circle" : "Dieser Benutzer ist bereits Mitglied dieses Kreises",
    "The user is already a member of this circle" : "Dieser Benutzer ist bereits Mitglied dieses Kreises ",
    "The user has already been invited into this circle" : "Benutzer wurde bereits zu diesem Kreis eingeladen",
    "This user does not exist" : "Dieser Benutzer existiert nicht",
    "Could not find share" : "Freigabe konnte nicht gefunden werden",
    "Circles allows your users to create their own groups of users/colleagues/friends.\nThose groups of users (or \"circles\") can then be used by any other app for sharing purpose." : "Mit Kreisen können deine Benutzer ihre eigenen Gruppen von Benutzern/Kollegen/Freunden erstellen.\nDiese Benutzergruppen (oder \"Kreise\") können dann von jeder anderen App zum Zweck der gemeinsamen Nutzung verwendet werden."
},
"nplurals=2; plural=(n != 1);");
